@@ -48,27 +48,6 @@ test( formula, "H2O", fn )
 test( formula, "C6H5OH", fn )
 test( formula, "NaCl", fn )
 
-
-# do the same thing with re's
-import re
-
-formula = "([A-Z][a-z]*[0-9]*)+"
-formulaRE = re.compile( formula )
-
-def test2( regex, strg, fn=None ):
-    m = regex.findall(strg)
-    ngroups = len(m)
-    if ngroups > 0:
-        for i in range(ngroups):
-            print m[i]
-    else:
-        print "no match"
-    print
-    
-fn = None
-test2( formulaRE, "H2O", fn )
-test2( formulaRE, "C6H5OH", fn )
-test2( formulaRE, "NaCl", fn )
     
 
 
